pub enum Code {
Show 21 variants
Required,
NullNotAllowed,
TypeMismatch,
OutOfRange,
UnsafeInteger,
IntegerTooWide,
NotFinite,
TooShort,
TooLong,
TooFewItems,
TooManyItems,
NotInEnum,
InvalidFormat,
InvalidDate,
InvalidDateTime,
MissingTimezone,
UnknownField,
UnknownVariant,
DepthExceeded,
SizeExceeded,
UnknownType,
}Variants
Required
NullNotAllowed
TypeMismatch
OutOfRange
UnsafeInteger
IntegerTooWide
NotFinite
TooShort
TooLong
TooFewItems
TooManyItems
NotInEnum
InvalidFormat
The string did not have the shape its @format names.
InvalidDate
InvalidDateTime
MissingTimezone
UnknownField
UnknownVariant
The tag named a variant the union does not declare.
DepthExceeded
SizeExceeded
UnknownType
Implementations